@@ -22,6 +22,10 @@ class SimplePriorityQueue(list):
             key, (0, key, value)
         )
 
+    def __iter__(self):
+        for _ in range(len(self)):
+            yield self.pop_pri()
+
     def append(self, obj: Any) -> None:
         self.push_pri(obj)
 
@@ -42,8 +46,12 @@ class SimplePriorityQueue(list):
 
 
 if __name__ == '__main__':
-    tmp = SimplePriorityQueue()
-    tmp.extend(range(10))
-    tmp.push_pri(100, 11)
-    tmp.push_pri(1000, 0)
-    print(tmp)
+    from random import randint
+
+    queue = SimplePriorityQueue()
+
+    for i in range(100):
+        queue.push_pri('*' * i, randint(1, 100))
+
+    print(queue)
+    [print(i) for i in queue]
